<?php $pageTitle='Sequences';
include realpath(__DIR__).'/../../core/_common/header.php'; ?>
<script type="text/javascript">
window.addEventListener('DOMContentLoaded',function(){


    const headers = ['Name', 'Project'];
    const cellTemplates = ['<a href="/sequence/{{id}}">{{name}}</a>', [Project.getLink,'name'] ];

    const grid = ui.grid();

    grid.box({
		classes:'r1 c1 h1 w3',
		content:'This is only for testing and development. Go to the project page for a better way to work with proteins, constructs and sequences.'
	});
	
	grid.box({ 
		classes:'r2 c1 h2 w3',
		url:'/api/sequence',
		headers:headers,
		cellTemplates:cellTemplates
	});


});
</script>
<?php include realpath(__DIR__).'/../../core/_common/footer.php';